<p align="center">
  <a href="https://github.com/godatadriven/pytest-dbt-core/blob/main/LICENSE"><img src="https://img.shields.io/badge/license-Apache%202-blue.svg" alt="License: Apache 2.0"></a>
  <a href="https://pypi.org/project/pytest-dbt-core/"><img alt="Pypi pytest-dbt-core" src="https://img.shields.io/badge/pypi-pytest%20dbt%20core-green.svg"></a>
  <a href="https://github.com/godatadriven/pytest-dbt-core/actions/workflows/workflow.yml"><img alt="build pytest-dbt-core" src="https://github.com/godatadriven/pytest-dbt-core/actions/workflows/workflow.yml/badge.svg"></a>
</p>

Pytest dbt core is a [pytest](https://docs.pytest.org) plugin for testing your
[dbt](https://www.getdbt.com/) projects. Write unit test for your dbt logic with
pytest!

# :information_desk_person: User documentation

The user documentation is hosted on
[read the docs](https://pytest-dbt-core.readthedocs.io/en/latest/).

# :raising_hand: Contributing guide

The contributing guide is [here](./CONTRIBUTING.md).

# :gift: How to release

The "how to release" guide is [here](./HOWTORELEASE.md).

# :cop: License

The license is given [here](./LICENSE).
